#import "Controller.h"
#import <VLC/VLCMediaControl.h>

static void *sleepForMe(void)
{
	while (1) sleep(60);
}

@implementation Controller

- (void)awakeFromNib
{
//	atexit((void*)sleepForMe);	// Only used for memory leak debugging

	[NSApp setDelegate:self];
    NSRect rect;

    /* Won't be released */
    videoView = [[VLCVideoView alloc] init];
    rect = [videoHolderView frame];
    [[window contentView] replaceSubview: videoHolderView with: videoView];
    [videoView setFrame: rect];
    [videoView setAutoresizingMask: NSViewHeightSizable|NSViewWidthSizable];

	controller = [[VLCMediaControl alloc] init];
	[controller setView:videoView];
	[[controller playlist] setDelegate:self];

    [playlistOutline registerForDraggedTypes:[NSArray arrayWithObjects:NSFilenamesPboardType, NSURLPboardType, nil]];
	[playlistOutline setDoubleAction:@selector(changeAndPlay:)];
}

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
}

- (void)applicationWillTerminate:(NSNotification *)aNotification
{
	[controller release];
	[videoView release];
}


- (void)changeAndPlay:(id)sender
{
	if ([playlistOutline selectedRow] != [controller mediaIndex])
	{
		[controller setMediaAtIndex:[playlistOutline selectedRow]];
		if (![[controller player] isPlaying])
			[[controller player] play];
	}
}

- (void)play:(id)sender
{
	[controller next];
	[[controller audio] setVolume:150];

	if (![[controller player] isPlaying])
		[[controller player] play];
}

- (void)pause:(id)sender
{
	NSLog(@"Sending pause message to media player...");
	[[controller player] pause];
}

//
- (void)mediaList:(VLCMediaList *)mediaList mediaAdded:(VLCMedia *)media atIndex:(int)index
{
	[playlistOutline reloadData];
}

- (void)mediaList:(VLCMediaList *)mediaList mediaRemoved:(VLCMedia *)media atIndex:(int)index
{
	[playlistOutline reloadData];
}

// NSTableView Implementation
- (int)numberOfRowsInTableView:(NSTableView *)tableView
{
	return [[controller playlist] count];
}

- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn
			row:(int)row
{
    return [[[controller playlist] mediaAtIndex:row] description];
}

- (NSDragOperation)tableView:(NSTableView*)tv validateDrop:(id <NSDraggingInfo>)info 
				 proposedRow:(int)row proposedDropOperation:(NSTableViewDropOperation)op
{
    return NSDragOperationEvery; /* This is for now */
}

- (BOOL)tableView:(NSTableView *)aTableView acceptDrop:(id <NSDraggingInfo>)info
			  row:(int)row dropOperation:(NSTableViewDropOperation)operation
{
    int i;
    NSArray *droppedItems = [[info draggingPasteboard] propertyListForType:NSFilenamesPboardType];
	
    for (i = 0; i < [droppedItems count]; i++)
    {
        NSString * filename = [droppedItems objectAtIndex:i];
		[[controller playlist] addMedia:[VLCMedia mediaWithURL:filename]];
    }
	return YES;
}	

@end
