/*****************************************************************************
 * VLCMediaControl.h: VLC.framework VLCMediaControl header
 *****************************************************************************
 * Copyright (C) 2007 Faustino E. Osuna
 * Copyright (C) 2007 the VideoLAN team
 * $Id:  $
 *
 * Authors: Faustino E. Osuna <enrique.osuna # gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import "VLCLibrary.h"
#import "VLCMediaPlayer.h"
#import "VLCAudio.h"

/* Notification Messages */
extern NSString *VLCMediaControlEndOfList;
extern NSString *VLCMediaControlStateChange;

// TODO: Documentation
@protocol VLCMediaControlDelegate

- (void)mediaControlEndOfList:(NSNotification *)aNotification;
- (void)mediaControlStateChange:(NSNotification *)aNotification;

@end

// TODO: Documentation
@interface VLCMediaControl : NSObject 
{
	VLCMediaList *playlist;			//< Singleton playlist for this instance
	VLCMediaPlayer *player;			//< Singleton media player for this instance 
	VLCAudio *audio;				//< Audio unit, shortcut to [library audio]
	VLCMediaPlayerState state;		//< Current media control state
	int currentMediaIndex;			//< Index of the current media that is being played or queued to play
}

/* Initializers */

/* Properties */
- (void)setView:(NSView *)view;
- (NSView *)view;
- (VLCMediaList *)playlist;
- (VLCMediaPlayer *)player;
- (VLCAudio *)audio;

/* Operations */
- (void)next;
- (void)previous;
- (void)setMedia:(VLCMedia *)media;
- (void)setMediaAtIndex:(int)index;
- (int)mediaIndex;
- (VLCMedia *)media;
- (VLCMediaPlayerState)state;

/* Delegate Implementations */
// Playlist Delegates
- (void)mediaListItemRemoved:(VLCMedia *)media atIndex:(int)index;

// Media Player Delegates
- (void)mediaPlayerStateChanged:(NSNotification *)aNotification;

@end
