/*****************************************************************************
 * VLCMediaControl.h: VLC.framework VLCMediaControl implementation
 *****************************************************************************
 * Copyright (C) 2007 Faustino E. Osuna
 * Copyright (C) 2007 the VideoLAN team
 * $Id:  $
 *
 * Authors: Faustino E. Osuna <enrique.osuna # gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#import "VLCMediaControl.h"

// TODO: When an item is added to the playlist and there is none currently set
// set that item as the first item to play.

/* Notification Messages */
NSString *VLCMediaControlEndOfList	 = @"VLCMediaControlEndOfList";
NSString *VLCMediaControlStateChange = @"VLCMediaControlStateChange";

@implementation VLCMediaControl

- (id)init
{
	if (self = [super init])
	{
		state = VLCMediaPlayerStateStopped;
		currentMediaIndex = -1;
		playlist = [[VLCMediaList alloc] init];
		player   = [[VLCMediaPlayer alloc] init];
		
		[playlist setDelegate:self];
		[player setDelegate:self];
		[player addObserver:self forKeyPath:@"media" options:NSKeyValueObservingOptionNew context:nil];
	}
	return self;
}

- (void)dealloc
{
	[player release];
	[playlist release];
	[super dealloc];
}

/* Properties */
- (void)setView:(NSView *)value
{
	[player setView:value];
}

- (NSView *)view
{
	return [player view];
}

- (VLCMediaList *)playlist
{
	return playlist;
}

- (VLCMediaPlayer *)player
{
	return player;
}

- (VLCAudio *)audio
{
	return [[VLCLibrary sharedLibrary] audio];
}

- (VLCMediaPlayerState)state
{
	return state;
}

- (void)next
{
	if ([playlist count] == 0)
	{
		// Nothing to play
		return;
	}
	else if (currentMediaIndex < [playlist count] - 1)
	{
		currentMediaIndex++;
	}
	else
	{
		//[self stop];
	}
//	else if (looping)
//	{
//		currentMediaIndex = 0;
//	}

	[self setMediaAtIndex:currentMediaIndex];
}

- (void)previous
{
	if ([playlist count] == 0)
	{
		// Nothing to play
		return;
	}
	else if (--currentMediaIndex < 0)
	{
		currentMediaIndex = 0;
	}
//	else if (looping)
//	{
//		currentMediaIndex = [playlist count] - 1;
//	}
	
	[self setMediaAtIndex:currentMediaIndex];
}

- (void)setMedia:(VLCMedia *)media
{
	if (media)
	{
		int index = [playlist indexOfMedia:media];
		if (index == -1)
			currentMediaIndex = [playlist addMedia:media];
		else
			currentMediaIndex = index;
		
		[self setMediaAtIndex:currentMediaIndex];
	}
	else
	{
		// TODO: Raise an error because media is non existant?
	}
}

- (void)setMediaAtIndex:(int)index
{
	if ([playlist count] == 0)
		return;
	
	[self willChangeValueForKey:@"media"];
	if (index <= 0)
		index = 0;
	else if (index >= [playlist count])
		index = [playlist count] - 1;
	currentMediaIndex = index;
	
	[player setMedia:[playlist mediaAtIndex:currentMediaIndex]];
	[self didChangeValueForKey:@"media"];
}

- (int)mediaIndex
{
	return currentMediaIndex;
}

- (VLCMedia *)media
{
	if (currentMediaIndex >= 0 && currentMediaIndex < [playlist count])
		return [playlist mediaAtIndex:currentMediaIndex];
	else
		return nil;
}

- (void)mediaListItemRemoved:(VLCMedia *)media atIndex:(int)index;
{
	// TODO: Check to see if the media deleted is the current media
	if (index == currentMediaIndex)
	{
		[self setMediaAtIndex:currentMediaIndex];
	}
}

- (void)mediaPlayerStateChanged:(NSNotification *)aNotification
{
	// TODO: Iterate to the next item, set the local state of the media controller
	if ([player state] == VLCMediaPlayerStateEnded)
	{
		[self next];
		[player play];
	}
}

- (void)observeValueForKeyPath:(NSString *)keyPath ofObject:(id)object 
						change:(NSDictionary *)change context:(void *)context
{
	if (keyPath == @"media")
	{
		if ([[player media] compare:[self media]] != NSOrderedSame)
		{			
			VLCMedia *media = [player media];
			if (media)
			{
				int index = [playlist indexOfMedia:media];
				if (index == -1)
					[playlist insertMedia:media atIndex:++currentMediaIndex];
				else
					currentMediaIndex = index;
				
				// Send delegate notification that the media has changed
				// TODO: Should delegate get the notification, or should it
				// be observing the player for these notifications?
//				if (delegate && [delegate respondsToSelector:@selector(observeValueForKeyPath:ofObject:change:context:)])
//					[delegate observeValueForKeyPath:keyPath ofObject:object 
//											  change:change context:context];
			}
		}
		return;
	}
}
@end
