/*****************************************************************************
 * VLCTime.h: VLC.framework VLCTime implementation
 *****************************************************************************
 * Copyright (C) 2007 Pierre d'Herbemont
 * Copyright (C) 2007 the VideoLAN team
 * $Id: VLCTime.m 21564M 2007-10-07 16:31:10Z (local) $
 *
 * Authors: Pierre d'Herbemont <pdherbemont # videolan.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#import <VLCTime.h>

static VLCTime *nullTime = nil;

@implementation VLCTime

+ (VLCTime *)nullTime
{
	if (!nullTime)
		nullTime = [VLCTime timeWithNumber:nil];
	return nullTime;
}

+ (VLCTime *)timeWithNumber:(NSNumber *)aNumber
{
	return [[[VLCTime alloc] initWithNumber:aNumber] autorelease];
}

// TODO: Implement [VLCTime timeWithString]
//+ (VLCTime *)timeWithString:(NSString *)aString
//{
//	return [[[VLCTime alloc] initWithString:aString] autorelease];
//}

- (id)initWithNumber:(NSNumber *)aNumber
{
    if (self = [super init])
    {
		if (aNumber)
			value = [aNumber copy];
		else
			value = nil;
    }
    return self;
}

// TODO: Implement [VLCTime initWithString]
//- (id)initWithString:(NSString *)aString
//{
//  // Sounds like a good idea but I really don't think there is any value added
//	if (self = [super init])
//	{
//		// convert value
//	}
//	return self;
//}

- (void)dealloc
{
    [value release];
    [super dealloc];
}

- (NSNumber *)numberValue
{
	if (value)
		return [[value copy] autorelease];
	else
		return nil;
}

- (NSString *)stringValue
{
	if (value)
	{
		int hours = [value intValue] / (3600 * 1000);
		int minutes = ([value intValue] - hours * 3600) / (60 * 1000);
		int seconds = ([value intValue] - hours * 3600 * 1000 - minutes * 60 * 1000) / 1000;
		
		return [NSString stringWithFormat:@"%02d:%02d:%02d", hours, minutes, seconds];
	}
	else
	{
		// Return a string that represents an undefined time.
		return @"--:--:--";
	}
}

- (NSComparisonResult)compare:(VLCTime *)aTime
{
    if (!aTime && !value)
		return NSOrderedSame;
	else if (!aTime)
		return NSOrderedDescending;
    else
        return [value compare:[aTime numberValue]];
}

- (NSString *)description
{
	return [self stringValue];
}

@end
